@@ -19,7 +19,8 @@ import pandas as pd
 import pandas.io.common
 import pint
 from dateutil import parser
-from openscm_units import unit_registry as ur
+
+import scmdata.units
 
 from ._base import OpsMixin
 from ._xarray import inject_xarray_methods
@@ -693,6 +694,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
             return NotImplemented
 
         is_scalar = isinstance(other, (numbers.Number, pint.Quantity))
+        ur = scmdata.units.get_unit_registry()
         if not is_scalar:
             other_ndim = len(other.shape)
             if other_ndim == 1:
@@ -735,7 +737,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
                 df._df.values[:] = res.T
             return df
 
-        return self.copy().groupby("unit").map(_perform_op)
+        return self.copy().groupby("unit").apply(_perform_op)
 
     def _unary_op(self, f, *args, **kwargs) -> Callable[..., "ScmRun"]:
         df = self.copy()
@@ -988,6 +990,58 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
         out = self._meta.get_level_values(col)
         return pd.Series(out, name=col, index=self._df.columns)
 
+    def set_meta(self, dimension: str, value: Any, **filter_kwargs: Any):
+        """
+        Update metadata
+
+        Optionally, a subset of metadata may be modified through the use of
+        additional `filter_kwargs` which are passed to :func:`filter`. The metadata
+        associated with the non-filtered timeseries are not modified.
+
+        This method does not preserve the order of the timeseries.
+
+        Parameters
+        ----------
+        dimension : str
+            Dimension of meta to update
+
+        value : Any
+            Value to set the targeted meta to
+
+        filter_kwargs : Any
+            Arguments used to filter which timeseries are updated
+
+            All the filtering functionality of :func:`filter` is available, except for
+            `"inplace"`.
+
+        See Also
+        --------
+        :func:`filter`
+
+        Returns
+        -------
+        :class:`BaseScmRun <scmdata.run.BaseScmRun>`
+            A new instance with the updated metadata.
+        """
+        keep = filter_kwargs.pop("keep", True)
+        log_if_empty = filter_kwargs.pop("log_if_empty", True)
+
+        if "inplace" in filter_kwargs:
+            raise ValueError("Inplace updating of metadata is not supported")
+
+        filtered_run = self.filter(
+            keep=keep, log_if_empty=log_if_empty, **filter_kwargs
+        )
+        filtered_run[dimension] = value
+        res = run_append(
+            [
+                filtered_run,
+                self.filter(keep=not keep, log_if_empty=False, **filter_kwargs),
+            ]
+        )
+
+        return res
+
     def filter(
         self,
         keep: bool = True,
@@ -1302,9 +1356,12 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
     def interpolate(
         self,
-        target_times: Union[np.ndarray, List[Union[dt.datetime, int]]],
+        target_times: Union[
+            np.ndarray, Iterable[Union[dt.datetime, dt.date, int, float]]
+        ],
         interpolation_type: str = "linear",
-        extrapolation_type: str = "linear",
+        extrapolation_type: Optional[str] = "linear",
+        uniform_year_length: bool = False,
     ):
         """
         Interpolate the data onto a new time frame.
@@ -1317,6 +1374,16 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
             Interpolation type. Options are 'linear'
         extrapolation_type: str or None
             Extrapolation type. Options are None, 'linear' or 'constant'
+        uniform_year_length: bool
+            If True, a 365-day calendar is assumed where each year has an equal length
+
+            By default, the interpolation takes into account the different number of
+            days in leap years.
+
+        Raises
+        ------
+        ValueError
+            If ``uniform_year_length=True`` and sub-annual timeseries are present
 
         Returns
         -------
@@ -1325,16 +1392,24 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
             :obj:`target_times` grid
         """
         # pylint: disable=protected-access
+        target_times: TimePoints = TimePoints(target_times)
+        source_times: TimePoints = self.time_points
 
-        target_times = np.asarray(target_times, dtype="datetime64[s]")
+        if uniform_year_length:
+            source_time_values = source_times.years()
+
+            if len(np.unique(source_time_values)) != len(source_times):
+                raise ValueError("Non-unique year values with uniform_year_length=True")
+            target_time_values = target_times.years()
+        else:
+            source_time_values = source_times.values
+            target_time_values = target_times.values
 
         res = self.copy()
 
-        target_times = TimePoints(target_times)
-
         timeseries_converter = TimeseriesConverter(
-            self.time_points.values,
-            target_times.values,
+            source_time_values,
+            target_time_values,
             interpolation_type=interpolation_type,
             extrapolation_type=extrapolation_type,
         )
@@ -1640,7 +1715,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
             ts.index = pd.MultiIndex.from_frame(ts_idx.fillna(na_override))
 
         group_cols = list(set(ts.index.names) - set(cols))
-        grouper = ts.groupby(group_cols)
+        grouper = ts.groupby(group_cols, group_keys=False)
 
         # This is a subset of the available functions
         #  https://pandas.pydata.org/pandas-docs/stable/reference/groupby.html
@@ -1808,6 +1883,47 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         return RunGroupBy(self, group)
 
+    def apply(self, func, *args, **kwargs):
+        """
+        Apply a function to each timeseries and append the results
+
+        `func` is called like `func(ar, *args, **kwargs)` for each :class:`ScmRun <scmdata.run.ScmRun>` ``ar``
+        in this group. If the result of this function call is None, than it is
+        excluded from the results.
+
+        The results are appended together using :func:`run_append`. The function
+        can change the size of the input :class:`ScmRun <scmdata.run.ScmRun>` as long as :func:`run_append`
+        can be applied to all results.
+
+        Examples
+        --------
+        .. code:: python
+
+            >>> def multiply_by_2(arr):
+            ...     variable = arr.get_unique_meta("variable", True)
+            ...     if variable == "Surface Temperature":
+            ...         return arr * 2
+            ...     return arr
+            >>> run.apply(multiply_by_2)
+
+        Parameters
+        ----------
+        func : function
+            Callable to apply to each timeseries.
+
+        ``*args``
+            Positional arguments passed to `func`.
+
+        ``**kwargs``
+            Used to call `func(ar, **kwargs)` for each array `ar`.
+
+        Returns
+        -------
+        applied : :class:`ScmRun <scmdata.run.ScmRun>`
+            The result of splitting, applying and combining this array.
+        """
+        return self.groupby(self.meta.columns).apply(func, *args, **kwargs)
+
     def get_meta_columns_except(self, *not_group):
         """
         Get columns in meta except a set
@@ -1934,7 +2050,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
         ret = to_convert
         if not to_convert.empty:
-            ret = ret.groupby("unit").map(apply_units)
+            ret = ret.groupby("unit").apply(apply_units)
 
         ret = run_append([ret, to_not_convert], inplace=inplace)
         if not inplace:
@@ -2265,11 +2381,11 @@ def _merge_metadata(metadata):
 
 
 def run_append(
-    runs,
+    runs: List[BaseScmRun],
     inplace: bool = False,
     duplicate_msg: Union[str, bool] = True,
     metadata: Optional[MetadataType] = None,
-):
+) -> Optional[BaseScmRun]:
     """
     Append together many objects.
 
@@ -2421,7 +2537,7 @@ def run_append(
         # Convert back from str
         for c in nan_cols[nan_cols].index:
             new_meta[c].replace("nan", np.nan, inplace=True)
-        for c, dtype in orig_dtypes.iteritems():
+        for c, dtype in orig_dtypes.items():
             new_meta[c] = new_meta[c].astype(dtype)
 
         ret._meta = pd.MultiIndex.from_frame(new_meta.astype("category"))
