@@ -14,7 +14,7 @@ import xarray as xr
 
 from scmdata import ScmRun
 from scmdata.netcdf import _get_xr_dataset_to_write, nc_to_run, run_to_nc
-from scmdata.testing import assert_scmdf_almost_equal
+from scmdata.testing import _check_pandas_less_110, assert_scmdf_almost_equal
 
 
 def test_run_to_nc(scm_run):
@@ -728,3 +728,23 @@ def test_run_to_nc_xarray_kwarg_passing_variable_renaming(
 
     # variable should be renamed so it matches what goes to disk
     mock_ds.to_netcdf.assert_called_with(out_fname, **call_kwargs)
+
+
+@pytest.mark.parametrize("shift_times", [0, -1000, 1000])
+def test_run_to_nc_different_eras(scm_run, shift_times):
+    tmp = scm_run.timeseries(time_axis="year-month")
+    tmp.columns = tmp.columns + shift_times
+    scm_run = ScmRun(tmp)
+
+    with tempfile.TemporaryDirectory() as tempdir:
+        out_fname = join(tempdir, "out.nc")
+        run_to_nc(scm_run, out_fname, dimensions=("scenario",))
+
+        with pytest.warns(None) as record:
+            res = nc_to_run(scm_run.__class__, out_fname)
+
+        if not _check_pandas_less_110():
+            # assert there weren't any warnings on loading
+            assert not record, " --- ".join([str(r) for r in record.list])
+
+    assert_scmdf_almost_equal(scm_run, res)
